@@ -16,13 +16,14 @@ class PR(Step, input_class=PRInputs, output_class=PROutputs):
         if self.inputs.get("modified_code_files") is not None:
             return
 
+        self.inputs["modified_code_files"] = []
+
         input_modified_files = self.inputs.get("modified_files")
         if input_modified_files is None or len(input_modified_files) < 1:
             return
 
         key_map = dict()
-        if self.inputs.get("path_key"):
-            key_map[self.inputs["path"]] = self.inputs["path_key"]
+        key_map["path"] = self.inputs.get("path_key", "path")
         if self.inputs.get("comment_title_key") is not None:
             key_map["commit_message"] = self.inputs["comment_title_key"]
         if self.inputs.get("comment_message_key") is not None:
