@@ -1,6 +1,8 @@
-from typing_extensions import Annotated, TypedDict, List
+from typing_extensions import Annotated, List, TypedDict
+
 from patchwork.common.utils.step_typing import StepTypeConfig
 
+
 class __ScanSonarRequiredInputs(TypedDict):
     sonarqube_api_key: Annotated[
         str,
@@ -20,6 +22,7 @@ You can find this in your SonarQube project settings.""",
         ),
     ]
 
+
 class ScanSonarInputs(__ScanSonarRequiredInputs, total=False):
     sonarqube_base_url: Annotated[
         str,
@@ -39,5 +42,6 @@ class SonarVulnerability(TypedDict):
     affectedCode: str
     messageText: str
 
+
 class ScanSonarOutputs(TypedDict):
     files_to_patch: List[SonarVulnerability]
